Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(554)

Unified Diff: content/browser/frame_host/navigation_controller_impl.h

Issue 1846653004: Rename IGNORING_CACHE to BYPASSING_CACHE (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/navigation_controller_impl.h
diff --git a/content/browser/frame_host/navigation_controller_impl.h b/content/browser/frame_host/navigation_controller_impl.h
index 8c6cf543741d81df3de99d7756df84a25c41d432..a0067f490515c2f78ac2e7343bb783c8c1639988 100644
--- a/content/browser/frame_host/navigation_controller_impl.h
+++ b/content/browser/frame_host/navigation_controller_impl.h
@@ -87,7 +87,7 @@ class CONTENT_EXPORT NavigationControllerImpl
bool IsInitialBlankNavigation() const override;
void Reload(bool check_for_repost) override;
void ReloadToRefreshContent(bool check_for_repost) override;
- void ReloadIgnoringCache(bool check_for_repost) override;
+ void ReloadBypassingCache(bool check_for_repost) override;
void ReloadOriginalRequestURL(bool check_for_repost) override;
void ReloadDisableLoFi(bool check_for_repost) override;
void NotifyEntryChanged(const NavigationEntry* entry) override;
@@ -299,7 +299,8 @@ class CONTENT_EXPORT NavigationControllerImpl
RenderFrameHostImpl* rfh,
const FrameHostMsg_DidCommitProvisionalLoad_Params& params);
// Helper function for code shared between Reload() and ReloadIgnoringCache().
void ReloadInternal(bool check_for_repost, ReloadType reload_type);
// Actually issues the navigation held in pending_entry.
@@ -433,7 +434,7 @@ class CONTENT_EXPORT NavigationControllerImpl
// The maximum number of entries that a navigation controller can store.
static size_t max_entry_count_for_testing_;
// If a repost is pending, its type (RELOAD or RELOAD_IGNORING_CACHE),
// NO_RELOAD otherwise.
ReloadType pending_reload_;
« no previous file with comments | « content/browser/frame_host/navigation_controller_android.cc ('k') | content/browser/frame_host/navigation_controller_impl.cc » ('j') | no next file with comments »
@@ -299,7 +299,8 @@ class CONTENT_EXPORT NavigationControllerImpl
RenderFrameHostImpl* rfh,
const FrameHostMsg_DidCommitProvisionalLoad_Params& params);
- // Helper function for code shared between Reload() and ReloadIgnoringCache().
+ // Helper function for code shared between Reload() and
+ // ReloadBypassingCache().
void ReloadInternal(bool check_for_repost, ReloadType reload_type);
// Actually issues the navigation held in pending_entry.
@@ -433,7 +434,7 @@ class CONTENT_EXPORT NavigationControllerImpl
// The maximum number of entries that a navigation controller can store.
static size_t max_entry_count_for_testing_;
- // If a repost is pending, its type (RELOAD or RELOAD_IGNORING_CACHE),
+ // If a repost is pending, its type (RELOAD or RELOAD_BYPASSING_CACHE),
// NO_RELOAD otherwise.
ReloadType pending_reload_;

Powered by Google App Engine
This is Rietveld 408576698